<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://competition.demo.getfoundni.co.uk
 * @since             1.0.0
 * @package           Gfni_Competition_Lists
 *
 * @wordpress-plugin
 * Plugin Name:       DIY Raffle: Entry Lists
 * Plugin URI:        https://competition.demo.getfoundni.co.uk
 * Description:       Create and Show Entry List on your website, this plugin needs ACF and raffle pick number to run.
 * Version:           1.0.0
 * Author:            Ryan Hull
 * Author URI:        https://competition.demo.getfoundni.co.uk
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gfni-competition-lists
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GFNI_COMPETITION_LISTS_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gfni-competition-lists-activator.php
 */
function activate_gfni_competition_lists() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gfni-competition-lists-activator.php';
	Gfni_Competition_Lists_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gfni-competition-lists-deactivator.php
 */
function deactivate_gfni_competition_lists() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gfni-competition-lists-deactivator.php';
	Gfni_Competition_Lists_Deactivator::deactivate();
}
 
 
register_activation_hook( __FILE__, 'activate_gfni_competition_lists' );
register_deactivation_hook( __FILE__, 'deactivate_gfni_competition_lists' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gfni-competition-lists.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gfni_competition_lists() {

	// Verify if Advanced Custom Fields PRO is activated
	add_action('admin_init', function() {
		if (is_admin() && current_user_can('activate_plugins') && (!class_exists('ACF') || !class_exists('Wc_Lottery_Pn'))) {
			add_action('admin_notices', function() {
				$notice = 'Sorry, but DIY Entry Lists Plugin requires that ACF & Raffle Plugins are installed and active.';
				echo "<div class='error'><p>$notice</p></div>";
			});
			deactivate_plugins(plugin_basename(__FILE__));
			if (isset($_GET['activate'])) {
				unset($_GET['activate']);
			}
		}
	});

	$plugin = new Gfni_Competition_Lists();
	$plugin->run();

}
run_gfni_competition_lists();
